package iotcloud;

import java.nio.ByteBuffer;
import java.util.Set;
import java.util.HashSet;

/**
 * This Entry records the abort sent by a given machine.
 * @author Ali Younis <ayounis@uci.edu>
 * @version 1.0
 */


class Commit extends Entry {
	private long seqnum;
	private Set<KeyValue> keyValueUpdateSet;


	public Commit(Slot slot, long _seqnum, long _machineid) {
		super(slot);
		seqnum=_seqnum;
		machineid=_machineid;
	}

	public long getSequenceNumber() {
		return seqnum;
	}





	static Entry decode(Slot slot, ByteBuffer bb) {
		long seqnum=bb.getLong();
		long machineid=bb.getLong();
		return new Abort(slot, seqnum, machineid);
	}

	public void encode(ByteBuffer bb) {
		bb.put(Entry.TypeAbort);
		bb.putLong(seqnum);
		bb.putLong(machineid);
	}

	public int getSize() {
		return 2*Long.BYTES+Byte.BYTES;
	}

	public byte getType() {
		return Entry.TypeAbort;
	}

	public Entry getCopy(Slot s) {
		return new Abort(s, seqnum, machineid);
	}
}